.. API index

``emdfile`` API
===============

``emdfile`` includes :doc:`read/write <io>` functions, :doc:`classes <classes/index>` for wrapping data and metadata and building trees, and some supporting :doc:`utility <utils>` methods.
Note that it also contains an :ref:`N-dimensional progress bar <tqdmnd>` utility, curtesy of `Steven E. Zeltmann <https://github.com/sezelt>`_.


.. toctree::
   :maxdepth: 4

   I/O <io.rst>
   Classes <classes/index.rst>
   Utilities <utils.rst>

